@@ -478,56 +478,6 @@ playlist_copy_location_action_callback (GtkAction *action, TotemPlaylist *playli
 	g_list_free (l);
 }
 
-static void
-totem_playlist_set_reorderable (TotemPlaylist *playlist, gboolean set)
-{
-	guint num_items, i;
-
-	gtk_tree_view_set_reorderable
-		(GTK_TREE_VIEW (playlist->priv->treeview), set);
-
-	if (set != FALSE)
-		return;
-
-	num_items = PL_LEN;
-	for (i = 0; i < num_items; i++)
-	{
-		GtkTreeIter iter;
-		char *index;
-		GtkTreePath *path;
-		TotemPlaylistStatus playing;
-
-		index = g_strdup_printf ("%d", i);
-		if (gtk_tree_model_get_iter_from_string
-				(playlist->priv->model,
-				 &iter, index) == FALSE)
-		{
-			g_free (index);
-			continue;
-		}
-		g_free (index);
-
-		gtk_tree_model_get (playlist->priv->model, &iter, PLAYING_COL, &playing, -1);
-		if (playing == TOTEM_PLAYLIST_STATUS_NONE)
-			continue;
-
-		/* Only emit the changed signal if we changed the ->current */
-		path = gtk_tree_path_new_from_indices (i, -1);
-		if (gtk_tree_path_compare (path, playlist->priv->current) == 0)
-		{
-			gtk_tree_path_free (path);
-		} else {
-			gtk_tree_path_free (playlist->priv->current);
-			playlist->priv->current = path;
-			g_signal_emit (G_OBJECT (playlist),
-					totem_playlist_table_signals[CHANGED],
-					0, NULL);
-		}
-
-		break;
-	}
-}
-
 static gboolean 
 button_press_cb (GtkWidget *treeview, GdkEventButton *event, gpointer data)
 { 
@@ -540,8 +490,6 @@ button_press_cb (GtkWidget *treeview, GdkEventButton *event, gpointer data)
 	gtk_drag_dest_unset (treeview);
 	g_signal_handlers_block_by_func (treeview, (GFunc) drop_cb, data);
 
-	totem_playlist_set_reorderable (playlist, TRUE);
-
 	return FALSE;
 }
 
@@ -553,7 +501,6 @@ button_release_cb (GtkWidget *treeview, GdkEventButton *event, gpointer data)
 	if (!playlist->priv->drag_started && playlist->priv->drop_disabled)
 	{
 		playlist->priv->drop_disabled = FALSE;
-		totem_playlist_set_reorderable (playlist, FALSE);
 		gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (treeview),
 						      target_table, G_N_ELEMENTS (target_table),
 						      GDK_ACTION_COPY | GDK_ACTION_MOVE);
@@ -582,7 +529,6 @@ drag_end_cb (GtkWidget *treeview, GdkDragContext *context, gpointer data)
 
 	playlist->priv->drop_disabled = FALSE;
 	playlist->priv->drag_started = FALSE;
-	totem_playlist_set_reorderable (playlist, FALSE);
 
 	gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (treeview),
 					      target_table, G_N_ELEMENTS (target_table),
@@ -1160,8 +1106,6 @@ treeview_row_changed (GtkTreeView *treeview, GtkTreePath *arg1,
 
 	if (playlist->priv->drop_disabled) {
 		playlist->priv->drop_disabled = FALSE;
-		totem_playlist_set_reorderable (playlist, FALSE);
-
 		gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (treeview),
 						      target_table, G_N_ELEMENTS (target_table),
 						      GDK_ACTION_COPY | GDK_ACTION_MOVE);
@@ -1197,7 +1141,6 @@ init_treeview (GtkWidget *treeview, TotemPlaylist *playlist)
 	init_columns (GTK_TREE_VIEW (treeview), playlist);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 	g_signal_connect (G_OBJECT (treeview), "row-activated",
 			G_CALLBACK (treeview_row_changed), playlist);
 
