@@ -51,6 +51,7 @@
 #endif
 
 #include "bacon-video-widget.h"
+#include "totem-dvb-setup.h"
 #include "totem-statusbar.h"
 #include "totem-time-label.h"
 #include "totem-session.h"
@@ -97,6 +98,7 @@ static const GtkTargetEntry target_table[] = {
 
 static gboolean totem_action_open_files (Totem *totem, char **list);
 static gboolean totem_action_open_files_list (Totem *totem, GSList *list);
+static gboolean totem_action_load_media (Totem *totem, TotemDiscMediaType type, const char *device);
 static void update_buttons (Totem *totem);
 static void playlist_changed_cb (GtkWidget *playlist, Totem *totem);
 static void play_pause_set_label (Totem *totem, TotemStates state);
@@ -455,6 +457,14 @@ totem_action_open_dialog (Totem *totem, const char *path, gboolean play)
 	return TRUE;
 }
 
+static void
+totem_dvb_setup_result (int result, const char *device, gpointer user_data)
+{
+	Totem *totem = (Totem *) user_data;
+
+	totem_action_load_media (totem, MEDIA_TYPE_DVB, device);
+}
+
 static gboolean
 totem_action_load_media (Totem *totem, TotemDiscMediaType type, const char *device)
 {
@@ -485,6 +495,10 @@ totem_action_load_media (Totem *totem, TotemDiscMediaType type, const char *devi
 		switch (status) {
 		case BVW_CAN_PLAY_MISSING_CHANNELS:
 			g_assert (type == MEDIA_TYPE_DVB);
+
+			if (totem_dvb_setup_device (device, GTK_WINDOW (totem->win), totem_dvb_setup_result, totem) == TOTEM_DVB_SETUP_STARTED_OK)
+				return FALSE;
+
 			link = "http://www.gnome.org/projects/totem/#dvb";
 			link_text = _("More information about watching TV");
 			msg = g_strdup (_("Totem is missing a channels listing to be able to tune the receiver."));
@@ -592,7 +606,9 @@ totem_action_play_media (Totem *totem, TotemDiscMediaType type, const char *devi
 	char *mrl;
 
 	if (totem_action_load_media (totem, type, device) != FALSE) {
+		g_message ("totem_action_play_media %s and != FALSE", device);
 		mrl = totem_playlist_get_current_mrl (totem->playlist, NULL);
+		g_message ("open and play %s", mrl);
 		totem_action_set_mrl_and_play (totem, mrl, NULL);
 		g_free (mrl);
 	}
@@ -842,14 +858,14 @@ totem_action_set_mrl_with_warning (Totem *totem,
 		totem->mrl = NULL;
 		bacon_video_widget_close (totem->bvw);
 		totem_file_closed (totem);
-		play_pause_set_label (totem, TOTEM_PLAYLIST_STATUS_NONE);
+		play_pause_set_label (totem, STATE_STOPPED);
 	}
 
 	if (mrl == NULL)
 	{
 		retval = FALSE;
 
-		play_pause_set_label (totem, TOTEM_PLAYLIST_STATUS_NONE);
+		play_pause_set_label (totem, STATE_STOPPED);
 
 		/* Play/Pause */
 		totem_action_set_sensitivity ("play", FALSE);
@@ -1101,7 +1117,7 @@ totem_action_zoom_relative (Totem *totem, int off_pct)
 void
 totem_action_zoom_reset (Totem *totem)
 {
-	totem_action_zoom (totem, 100);
+	totem_action_zoom (totem, ZOOM_RESET);
 }
 
 void
@@ -1315,25 +1331,6 @@ drag_video_cb (GtkWidget *widget,
 	g_free (text);
 }
 
-static void
-on_got_redirect (BaconVideoWidget *bvw, const char *mrl, Totem *totem)
-{
-	gchar *old_mrl, *new_mrl;
-
-	old_mrl = totem_playlist_get_current_mrl (TOTEM_PLAYLIST (totem->playlist), NULL);
-	new_mrl = totem_pl_parser_resolve_url (old_mrl, mrl);
-	g_free (old_mrl);
-
-	bacon_video_widget_close (totem->bvw);
-	totem_file_closed (totem);
-	totem_gdk_window_set_waiting_cursor (totem->win->window);
-	bacon_video_widget_open (totem->bvw, new_mrl, NULL);
-	totem_file_opened (totem, new_mrl);
-	gdk_window_set_cursor (totem->win->window, NULL);
-	bacon_video_widget_play (bvw, NULL);
-	g_free (new_mrl);
-}
-
 /* This is only called when we are playing a DVD or a radio */
 static void
 on_title_change_event (BaconVideoWidget *bvw, const char *string, Totem *totem)
@@ -1658,7 +1655,7 @@ totem_action_open_files_list (Totem *totem, GSList *list)
 				totem_playlist_add_mrl (totem->playlist, data, NULL);
 				changed = TRUE;
 			} else if (g_str_equal (filename, "dvb:") != FALSE) {
-				totem_action_play_media (totem, MEDIA_TYPE_DVB, "0");
+				totem_action_load_media (totem, MEDIA_TYPE_DVB, "0");
 				changed = TRUE;
 			} else if (totem_playlist_add_mrl (totem->playlist, filename, NULL) != FALSE) {
 				changed = TRUE;
@@ -1709,7 +1706,6 @@ show_controls (Totem *totem, gboolean was_fullscreen)
 		gtk_widget_set_sensitive (menubar, TRUE);
 		gtk_widget_show (menubar);
 		gtk_widget_show (controlbar);
-		gtk_widget_show (statusbar);
 		if (totem_sidebar_is_visible (totem) != FALSE) {
 			/* This is uglier then you might expect because of the
 			   resize handle between the video and sidebar. There
@@ -1854,7 +1850,7 @@ totem_action_remote (Totem *totem, TotemRemoteCommand cmd, const char *url)
 			/* FIXME b0rked */
 			totem_action_play_media (totem, MEDIA_TYPE_VCD, NULL);
 		} else if (g_str_has_prefix (url, "dvb:") != FALSE) {
-			totem_action_play_media (totem, MEDIA_TYPE_DVB, "0");
+			totem_action_load_media (totem, MEDIA_TYPE_DVB, "0");
 		} else {
 			totem_playlist_add_mrl_with_cursor (totem->playlist, url, NULL);
 		}
@@ -1973,7 +1969,7 @@ playlist_changed_cb (GtkWidget *playlist, Totem *totem)
 static void
 item_activated_cb (GtkWidget *playlist, Totem *totem)
 {
-	totem_action_seek (totem, 0);
+	playlist_changed_cb (playlist, totem);
 }
 
 static void
@@ -2079,27 +2075,11 @@ on_video_button_press_event (BaconVideoWidget *bvw, GdkEventButton *event,
 static gboolean
 on_eos_event (GtkWidget *widget, Totem *totem)
 {
-	if (bacon_video_widget_get_logo_mode (totem->bvw) != FALSE)
-		return FALSE;
-
-	if (totem_playlist_has_next_mrl (totem->playlist) == FALSE
-			&& totem_playlist_get_repeat (totem->playlist) == FALSE)
-	{
-		char *mrl, *subtitle;
-
-		/* Set play button status */
-		totem_playlist_set_at_start (totem->playlist);
-		update_buttons (totem);
-		totem_action_stop (totem);
-		mrl = totem_playlist_get_current_mrl (totem->playlist, &subtitle);
-		totem_action_set_mrl_with_warning (totem, mrl, subtitle, FALSE);
-		bacon_video_widget_pause (totem->bvw);
-		g_free (mrl);
-		g_free (subtitle);
-	} else {
-		totem_action_next (totem);
-	}
-
+	bacon_video_widget_stop (totem->bvw);
+	play_pause_set_label (totem, STATE_STOPPED);
+	totem_action_error (_("TV signal lost"),
+			    _("Please verify your hardware setup."),
+			    totem);
 	return FALSE;
 }
 
@@ -2580,10 +2560,6 @@ video_widget_create (Totem *totem)
 			"eos",
 			G_CALLBACK (on_eos_event),
 			totem);
-	g_signal_connect (G_OBJECT (totem->bvw),
-			"got-redirect",
-			G_CALLBACK (on_got_redirect),
-			totem);
 	g_signal_connect (G_OBJECT(totem->bvw),
 			"title-change",
 			G_CALLBACK (on_title_change_event),
@@ -2844,6 +2820,8 @@ main (int argc, char **argv)
 	if (optionstate.fullscreen == FALSE)
 		gdk_window_set_cursor (totem->win->window, NULL);
 
+	totem_action_zoom_reset (totem);
+
 	if (totem->conn != NULL && bacon_message_connection_get_is_server (totem->conn) != FALSE)
 	{
 		bacon_message_connection_set_callback (totem->conn,
